@@ -6,7 +6,7 @@ from cliff.commandmanager import CommandManager
 
 class DemoApp(App):
     def __init__(self):
-        super(DemoApp, self).__init__(
+        super().__init__(
             description='cliff demo app',
             version='0.1',
             command_manager=CommandManager('cliff.demo'),
